=========
Changelog
=========

Unreleased
==========

Version 0.6
===========
- Rainforest and LC classes available at the 0.1 degree grid.

Version 0.5
===========

- Antarctica masked on 0.1 degree grid
- Antarctica on 0.1 still available in: ESA-CCI-SOILMOISTURE-LAND_AND_RAINFOREST_MASK_ANTARCTICA-fvMR01.0.nc

Version 0.4
===========
- Update metapackage to pyscaffold 4
- Add medium resolution CCI grid (0.1°)

Version 0.3
===========
- Add more examples on how to use the grids in docs
- Flip lats in grid v5 so that gpi can be used for indexing arrays
- New pyscaffold structure
- Travis pypi deployment

Version 0.2
===========
- Add Version 05.2 grid definition
- Add high VOD mask and ESA CCI LC classes.
- Allow reducing grid based on ESA CCI LC classes
- Allow reducing grid based on Koeppen-Geiger climate classes

Version 0.1
===========
- First version of package, including grid version 04.2
- Basic documentation
- Public pypi release
